diff --git a/CEP/Pipeline/recipes/sip/bin/startPython.sh b/CEP/Pipeline/recipes/sip/bin/startPython.sh
index 718f1dcafc7ffa52c50af46062d12ca59ffb5fa0..11caabd5e7ada8e6df318f44b63d8d557e72238f 100755
--- a/CEP/Pipeline/recipes/sip/bin/startPython.sh
+++ b/CEP/Pipeline/recipes/sip/bin/startPython.sh
@@ -7,7 +7,7 @@
 #
 # For example:
 #
-#   startPython.sh ./pythonProgram /opt/lofar/share/Observation6118 \
+#   startPython.sh ./pythonProgram /opt/lofar/var/run/Observation6118 \
 #                  MCU001T MCU001T:PythonControl[0]{6118}:listener  \
 #                  PythonServer{6118}@MCU001T 
 #
@@ -23,7 +23,7 @@ shopt -s expand_aliases
 debug=on
 
 # Log-file used for logging output of this script
-logFile=/opt/lofar/log/startPython.log
+logFile=/opt/lofar/var/log/startPython.log
 
 usage()
 {
@@ -45,7 +45,7 @@ programOptions=" \
  -d \
  -c ${LOFARROOT}/share/pipeline/pipeline.cfg \
  -t ${LOFARROOT}/share/pipeline/tasks.cfg \
- -r ${LOFARROOT}/share/pipeline \
+ -r ${LOFARROOT}/var/run/pipeline \
  -w /data/scratch/${USER}"
   
 # Print some debugging information if debugging is enabled.
diff --git a/CEP/Pipeline/recipes/sip/pipeline.cfg.in b/CEP/Pipeline/recipes/sip/pipeline.cfg.in
index 3190c9ca7fc6b85ba8ba3d7f0386a2d78e49f3e1..ceb346107380b7d705dec7568f370e5326c6aed4 100644
--- a/CEP/Pipeline/recipes/sip/pipeline.cfg.in
+++ b/CEP/Pipeline/recipes/sip/pipeline.cfg.in
@@ -5,7 +5,7 @@ pyraproot = @PYRAP_ROOT_DIR@
 hdf5root = $ENV{HDF5_ROOT}
 wcsroot = @WCSLIB_ROOT_DIR@
 pythonpath = @PYTHON_INSTALL_DIR@
-runtime_directory = %(lofarroot)s/share/pipeline
+runtime_directory = %(lofarroot)s/var/run/pipeline
 recipe_directories = [%(pythonpath)s/lofarpipe/recipes]
 working_directory = /data/scratch/$ENV{USER}
 task_files = [%(lofarroot)s/share/pipeline/tasks.cfg]
diff --git a/LCS/ApplCommon/include/ApplCommon/StationInfo.h b/LCS/ApplCommon/include/ApplCommon/StationInfo.h
index d37c7eb9b240aa6543a39d01a59e55e26fc5fd9c..45ac4c2c743ce09f94ddda796cbc1c7d6e94a9f5 100644
--- a/LCS/ApplCommon/include/ApplCommon/StationInfo.h
+++ b/LCS/ApplCommon/include/ApplCommon/StationInfo.h
@@ -39,8 +39,8 @@ namespace LOFAR {
 #define LOFAR_BASE_LOCATION		"/opt/lofar"
 #define LOFAR_BIN_LOCATION		"/opt/lofar/bin"
 #define LOFAR_CONFIG_LOCATION	"/opt/lofar/etc"
-#define LOFAR_SHARE_LOCATION	"/opt/lofar/share"
-#define LOFAR_LOG_LOCATION		"/opt/lofar/log"
+#define LOFAR_SHARE_LOCATION	"/opt/lofar/var/run"
+#define LOFAR_LOG_LOCATION		"/opt/lofar/var/log"
 
 //
 // Nameconventions dictate that the hostname has the following syntax:
diff --git a/MAC/APL/Appl_Controller/lofarDirs.h b/MAC/APL/Appl_Controller/lofarDirs.h
index facc48ccb56941e1d7c737f3c3b707a9fd7ecf70..9b24e38a61c50626b9c5c6bb7d1dffc4438b6c1c 100644
--- a/MAC/APL/Appl_Controller/lofarDirs.h
+++ b/MAC/APL/Appl_Controller/lofarDirs.h
@@ -23,6 +23,6 @@
 #ifndef ACCBIN_LOFARDIRS_H
 #define ACCBIN_LOFARDIRS_H
 
-#define	LOFAR_SHARE_LOCATION		"/opt/lofar/share"
+#define	LOFAR_SHARE_LOCATION		"/opt/lofar/var/run"
 
 #endif
diff --git a/MAC/APL/Appl_Controller/startAP.sh b/MAC/APL/Appl_Controller/startAP.sh
index cd645a5707db192a3846165baaa4c4efe23a12a2..ce8d145a1c57e8973112d16b82565aa61ec14b32 100755
--- a/MAC/APL/Appl_Controller/startAP.sh
+++ b/MAC/APL/Appl_Controller/startAP.sh
@@ -21,4 +21,4 @@ $3 ACC $4 $2 &
 pid=`echo $!`
 
 # construct pid file for stop shell
-echo "$pid" > /opt/lofar/share/$2.pid
+echo "$pid" > /opt/lofar/var/run/$2.pid
diff --git a/MAC/APL/Appl_Controller/stopAP.sh b/MAC/APL/Appl_Controller/stopAP.sh
index 651e2dc6ed1df7157dfcb851a3e4e677cf0d520b..1984d5a8a53eaee28706a52c5e607adedf99c2aa 100755
--- a/MAC/APL/Appl_Controller/stopAP.sh
+++ b/MAC/APL/Appl_Controller/stopAP.sh
@@ -9,6 +9,6 @@
 # DISABLED this script: startBGL.sh starts all CEP processes
 exit
 
-echo -n "Killing process "; cat /opt/lofar/share/$2.pid
-kill -9 `cat /opt/lofar/share/$2.pid`
-rm -f /opt/lofar/share/$2.pid /opt/lofar/share/$2.parset
+echo -n "Killing process "; cat /opt/lofar/var/run/$2.pid
+kill -9 `cat /opt/lofar/var/run/$2.pid`
+rm -f /opt/lofar/var/run/$2.pid /opt/lofar/var/run/$2.parset
diff --git a/MAC/APL/TestCtlr/src/ControllerMenu.cc b/MAC/APL/TestCtlr/src/ControllerMenu.cc
index 9f115e11fb180adc04c6c978eafe32010b93d07a..3b5f72df37db8e5f43429192f049b449e6d57108 100644
--- a/MAC/APL/TestCtlr/src/ControllerMenu.cc
+++ b/MAC/APL/TestCtlr/src/ControllerMenu.cc
@@ -547,8 +547,8 @@ void ControllerMenu::_doStartMenu()
 {
 	cout << endl;
 	cout << "You need an exportFile from OTDB containing an Observation." << endl;
-	cout << "Its name has the format /opt/lofar/share/Observation<nr>." << endl;
-	string	command("ls -1 /opt/lofar/share/Observation[0-9]*");
+	cout << "Its name has the format /opt/lofar/var/run/Observation<nr>." << endl;
+	string	command("ls -1 /opt/lofar/var/run/Observation[0-9]*");
 	system(command.c_str());
 
 	int32	obsnr(-1);
@@ -562,7 +562,7 @@ void ControllerMenu::_doStartMenu()
 			return;
 		}
 		ifstream	iFile;
-		string obsFileName(formatString("/opt/lofar/share/Observation%d", obsnr));
+		string obsFileName(formatString("/opt/lofar/var/run/Observation%d", obsnr));
 		iFile.open(obsFileName.c_str(), ifstream::in);
 		if (!iFile) {
 			cout << endl << "Cannot open file " << obsFileName << endl;
diff --git a/RTCP/CNProc/test/tCN_Processing_alloc.parset b/RTCP/CNProc/test/tCN_Processing_alloc.parset
index 0e5bde807731b7a74601ae29d42f518acf5db0fd..bc489a5b1d71a05b8cff9cc9e240f0065406c08b 100644
--- a/RTCP/CNProc/test/tCN_Processing_alloc.parset
+++ b/RTCP/CNProc/test/tCN_Processing_alloc.parset
@@ -1,7 +1,7 @@
 ApplCtrl.application = CorrAppl
 ApplCtrl.procesOrder = []
 ApplCtrl.processes = [CorrProc]
-ApplCtrl.resultfile = '/opt/lofar/share/ACC_CCU001:OnlineControl[0]{31821}_CorrAppl_result.param'
+ApplCtrl.resultfile = '/opt/lofar/var/run/ACC_CCU001:OnlineControl[0]{31821}_CorrAppl_result.param'
 ApplCtrl.timeout_createsubsets = 30s
 ApplCtrl.timeout_define = 30s
 ApplCtrl.timeout_info = 30s
diff --git a/RTCP/Storage/test/tMeasurementSetFormat.parset-j2000 b/RTCP/Storage/test/tMeasurementSetFormat.parset-j2000
index bd6e73f0054e228bf72eec4f1cdc8323a1da7881..4b18640835c1e8f55cb96b4c4e96f8968ab8f14e 100644
--- a/RTCP/Storage/test/tMeasurementSetFormat.parset-j2000
+++ b/RTCP/Storage/test/tMeasurementSetFormat.parset-j2000
@@ -1,7 +1,7 @@
 ApplCtrl.application = CorrAppl
 ApplCtrl.procesOrder = []
 ApplCtrl.processes = [CNProc]
-ApplCtrl.resultfile = '/opt/lofar/share/ACC_CCU001:OnlineControl[0]{24523}_CorrAppl_result.param'
+ApplCtrl.resultfile = '/opt/lofar/var/run/ACC_CCU001:OnlineControl[0]{24523}_CorrAppl_result.param'
 ApplCtrl.timeout_createsubsets = 3m
 ApplCtrl.timeout_define = 40
 ApplCtrl.timeout_info = 30
diff --git a/RTCP/Storage/test/tMeasurementSetFormat.parset-sun b/RTCP/Storage/test/tMeasurementSetFormat.parset-sun
index f03080e0b673f6f8715011bf8af99985bc16ff6b..8e8bd1da6cbf7640f7cb2e763e906533fee9c86c 100644
--- a/RTCP/Storage/test/tMeasurementSetFormat.parset-sun
+++ b/RTCP/Storage/test/tMeasurementSetFormat.parset-sun
@@ -1,7 +1,7 @@
 ApplCtrl.application = CorrAppl
 ApplCtrl.procesOrder = []
 ApplCtrl.processes = [CNProc]
-ApplCtrl.resultfile = '/opt/lofar/share/ACC_CCU001:OnlineControl[0]{24523}_CorrAppl_result.param'
+ApplCtrl.resultfile = '/opt/lofar/var/run/ACC_CCU001:OnlineControl[0]{24523}_CorrAppl_result.param'
 ApplCtrl.timeout_createsubsets = 3m
 ApplCtrl.timeout_define = 40
 ApplCtrl.timeout_info = 30
diff --git a/SAS/Beaminfo/src/failedtilesinfo.cc b/SAS/Beaminfo/src/failedtilesinfo.cc
index 880d0dee591a59416c4fa11daae997ff3cbeea5b..404d3c78498794f990f9fb51e817d03d825acc70 100644
--- a/SAS/Beaminfo/src/failedtilesinfo.cc
+++ b/SAS/Beaminfo/src/failedtilesinfo.cc
@@ -145,8 +145,8 @@ int main (int argc, char* argv[])
     string password    = parset.getString("password", "boskabouter");
     string port        = parset.getString("port", "5432");
     // Locations to save SAS hardware strings of broken and failed tiles to
-    string brokenfilename = parset.getString("brokenTilesFile", "/opt/lofar/share/brokenTiles.txt");
-    string failedfilename = parset.getString("failedTilesFile", "/opt/lofar/share/failedTiles.txt");
+    string brokenfilename = parset.getString("brokenTilesFile", "/opt/lofar/var/run/brokenTiles.txt");
+    string failedfilename = parset.getString("failedTilesFile", "/opt/lofar/var/run/failedTiles.txt");
 
     //---------------------------------------------------------------------
     // Handle observation starttime and endtime
diff --git a/MAC/APL/CEPCU/src/CEPlogProcessor/CEPlogProcessor.cc b/MAC/APL/CEPCU/src/CEPlogProcessor/CEPlogProcessor.cc
index 25296ce4a30bc980d15c6056794ae950575ee5bf..cc5906d4776253395fcbe53b584075dfe7f98bf9 100644
--- a/MAC/APL/CEPCU/src/CEPlogProcessor/CEPlogProcessor.cc
+++ b/MAC/APL/CEPCU/src/CEPlogProcessor/CEPlogProcessor.cc
@@ -412,8 +412,8 @@ void CEPlogProcessor::processParset( const std::string &observationID )
       return;
     }
 
-    // parsets are in /opt/lofar/share
-    string filename(formatString("/opt/lofar/share/Observation%s", observationID.c_str()));
+    // parsets are in /opt/lofar/var/run
+    string filename(formatString("/opt/lofar/var/run/Observation%s", observationID.c_str()));
 
     ParameterSet parset(filename);
 